#!/usr/bin/env python
# coding=utf-8

# Written by Tavmjong Bah

import re

import inkex

class BusinessCard(inkex.EffectExtension):
    def __init__(self):
        super(BusinessCard, self).__init__()
        self.arg_parser.add_argument("-s", "--size", type=str, dest="card_size",
                                     default="90mmx55mm", help="Business card size")

    def effect(self):
        size = self.options.card_size

        p = re.compile('([0-9.]*)([a-z][a-z])x([0-9.]*)([a-z][a-z])')
        m = p.match(size)
        width = m.group(1)
        width_unit = m.group(2)
        height = m.group(3)
        height_unit = m.group(4)

        root = self.document.getroot()
        root.set("id", "SVGRoot")
        root.set("width", width + width_unit)
        root.set("height", height + height_unit)
        root.set("viewBox", "0 0 " + width + " " + height)

        namedview = self.svg.namedview
        namedview.set(inkex.addNS('document-units', 'inkscape'), width_unit)

        width_int = int(self.svg.uutounit(float(width), 'px'))
        height_int = int(self.svg.uutounit(float(height), 'px'))

        namedview.set(inkex.addNS('zoom', 'inkscape'), str(2))
        namedview.set(inkex.addNS('cx', 'inkscape'), str(width_int / 2.0))
        namedview.set(inkex.addNS('cy', 'inkscape'), str(height_int / 2.0))


if __name__ == '__main__':
    BusinessCard().run()
